package com.ruoyi.abuwx.service.impl;

import com.ruoyi.abuwx.domain.CardRedeption;
import com.ruoyi.abuwx.mapper.CardRedeptionMapper;
import com.ruoyi.abuwx.service.ICardRedeptionService;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 卡券兑换Service业务层处理
 *
 * @author lujie
 * @date 2025-01-07
 */
@Service
public class CardRedeptionServiceImpl implements ICardRedeptionService {
    @Autowired
    private CardRedeptionMapper cardRedeptionMapper;

    /**
     * 查询卡券兑换
     *
     * @param id 卡券兑换主键
     * @return 卡券兑换
     */
    @Override
    public CardRedeption selectCardRedeptionById(Long id) {
        return cardRedeptionMapper.selectCardRedeptionById(id);
    }

    /**
     * 查询卡券兑换列表
     *
     * @param cardRedeption 卡券兑换
     * @return 卡券兑换
     */
    @Override
    public List<CardRedeption> selectCardRedeptionList(CardRedeption cardRedeption) {
        return cardRedeptionMapper.selectCardRedeptionList(cardRedeption);
    }

    /**
     * 新增卡券兑换
     *
     * @param cardRedeption 卡券兑换
     * @return 结果
     */
    @Override
    public int insertCardRedeption(CardRedeption cardRedeption) {
        cardRedeption.setCreateTime(DateUtils.getNowDate());
        return cardRedeptionMapper.insertCardRedeption(cardRedeption);
    }

    /**
     * 修改卡券兑换
     *
     * @param cardRedeption 卡券兑换
     * @return 结果
     */
    @Override
    public int updateCardRedeption(CardRedeption cardRedeption) {
        cardRedeption.setUpdateTime(DateUtils.getNowDate());
        return cardRedeptionMapper.updateCardRedeption(cardRedeption);
    }

    /**
     * 批量删除卡券兑换
     *
     * @param ids 需要删除的卡券兑换主键
     * @return 结果
     */
    @Override
    public int deleteCardRedeptionByIds(Long[] ids) {
        return cardRedeptionMapper.deleteCardRedeptionByIds(ids);
    }

    /**
     * 删除卡券兑换信息
     *
     * @param id 卡券兑换主键
     * @return 结果
     */
    @Override
    public int deleteCardRedeptionById(Long id) {
        return cardRedeptionMapper.deleteCardRedeptionById(id);
    }
}
